==> modpagespeed-1.8.31.6.tar.xz: modpagespeed-1.8.31.6/net/instaweb/genfiles/rewriter/console_js_opt.js <==
(function(){var f=Object,g=document,k="appendChild",l="evaluate",m="createElement",n="setAttribute",q="propertyIsEnumerable",r="push",s="length",t="prototype",u="call",v=function(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof f)return b;var c=f[t].toString[u](a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a[s]&&"undefined"!=typeof a.splice&&"undefined"!=typeof a[q]&&!a[q]("splice"))return"array";if("[object Function]"==c||"undefined"!=
typeof a[u]&&"undefined"!=typeof a[q]&&!a[q]("call"))return"function"}else return"null";else if("function"==b&&"undefined"==typeof a[u])return"object";return b},w="closure_uid_"+(1E9*Math.random()>>>0),x=0;var y="StopIteration"in this?this.StopIteration:Error("StopIteration"),z=function(){};z[t].a=function(){throw y;};z[t].d=function(){return this};var A=function(a){var b=[],c=0,d;for(d in a)b[c++]=a[d];return b};var C=function(a,b){this.a={};this.b=[];this.f=this.e=0;var c=arguments[s];if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)this.set(arguments[d],arguments[d+1])}else if(a){if(a instanceof C)D(a),d=a.b.concat(),c=a.g();else{var c=[],e=0;for(d in a)c[e++]=d;d=c;c=A(a)}for(e=0;e<d[s];e++)this.set(d[e],c[e])}};C[t].g=function(){D(this);for(var a=[],b=0;b<this.b[s];b++)a[r](this.a[this.b[b]]);return a};
var D=function(a){if(a.e!=a.b[s]){for(var b=0,c=0;b<a.b[s];){var d=a.b[b];f[t].hasOwnProperty[u](a.a,d)&&(a.b[c++]=d);b++}a.b.length=c}if(a.e!=a.b[s]){for(var e={},c=b=0;b<a.b[s];)d=a.b[b],f[t].hasOwnProperty[u](e,d)||(a.b[c++]=d,e[d]=1),b++;a.b.length=c}};C[t].set=function(a,b){f[t].hasOwnProperty[u](this.a,a)||(this.e++,this.b[r](a),this.f++);this.a[a]=b};
C[t].d=function(a){D(this);var b=0,c=this.b,d=this.a,e=this.f,h=this,p=new z;p.a=function(){for(;;){if(e!=h.f)throw Error("The map has changed since the iterator was created");if(b>=c[s])throw y;var p=c[b++];return a?p:d[p]}};return p};var E=function(a){if("function"==typeof a.g)return a.g();if("string"==typeof a)return a.split("");var b=v(a);if("array"==b||"object"==b&&"number"==typeof a[s]){for(var b=[],c=a[s],d=0;d<c;d++)b[r](a[d]);return b}return A(a)};var G=function(a){this.a=new C;a&&F(this,a)},H=function(a){var b=typeof a;return"object"==b&&a||"function"==b?"o"+(a[w]||(a[w]=++x)):b.substr(0,1)+a},F=function(a,b){for(var c=E(b),d=c[s],e=0;e<d;e++){var h=c[e];a.a.set(H(h),h)}};G[t].g=function(){return this.a.g()};G[t].d=function(){return this.a.d(!1)};google.load("visualization","1.0",{packages:["corechart"]});
var I=function(a){window.console&&console.error(a)},J=function(){this.a=[];this.f=new G;this.d=this.e=null;this.n={width:900,height:255,colors:["#4ECDC4","#556270","#C7F464"],legend:{position:"bottom"},hAxis:{format:"MMM d, y hh:mma",gridlines:{color:"#F2F2F2"},baselineColor:"#E5E5E5"},vAxis:{format:"#.###%",minValue:0,viewWindowMode:"explicit",viewWindow:{min:0},gridlines:{color:"#F2F2F2"},baselineColor:"#E5E5E5"},chartArea:{left:60,top:20,width:800},pointSize:2}},K=function(a){var b={};b.c=new G([a]);
b.evaluate=function(b){return b(a)};return b},L=function(a){var b={};b.c=new G;for(var c=0;c<a[s];c++)F(b.c,a[c].c);b.evaluate=function(b){for(var c=0,h=0;h<a[s];h++)c+=a[h][l](b);return c};return b},M=function(a,b){var c={};c.c=new G;F(c.c,a.c);F(c.c,b.c);c.evaluate=function(c){var e=b[l](c);return 0==e?0:a[l](c)/e};return c},N=function(a,b){return M(a,L([a,b]))},O=function(a,b,c,d){var e={};e.title=b;e.l="https://developers.google.com/speed/pagespeed/module/console#"+c;e.value=d;e.m=a.a[s];e.h=
null;e.i=null;e.j=null;e.k=null;a.a[r](e);F(a.f,d.c)},P=function(a,b,c){var d=pagespeedStatisticsUrl+"?json",d=d+("&start_time="+b.getTime()),d=d+("&end_time="+c.getTime()),d=d+"&granularity=60000&var_titles=";for(b=0;b<a[s];b++)d+=a[b]+",";return d},R=function(a,b,c){var d=new XMLHttpRequest;b=P(a.f.g(),b,c);d.onreadystatechange=function(){if(4==this.readyState)if(200!=this.status||1>this.responseText[s]||"{"!=this.responseText[0])I("XHR request failed.");else{var b=JSON.parse(this.responseText);
Q(a,b)}};d.open("GET",b);d.send()},Q=function(a,b){a.e=b.variables;a.d=b.timestamps;S(a.d,a.e);for(var c=0;c<a.a[s];c++){for(var d=[],e=0;e<a.d[s];e++)d[r](a.a[c].value[l](function(a){return function(b){if(b in a)return a[b][e];I("JSON data missing required variable.")}}(a.e)));a.a[c].h=d[d[s]-1];a.a[c].i=a.a[c].h;a.a[c].j=T(a.a[c].title,a.d,d)}a.a.sort(function(a,b){return b.i-a.i});for(c=0;c<a.a[s];c++)U(a,a.a[c])},S=function(a,b){for(var c in b)a[s]!=b[c][s]&&I("JSON response is malformed. ("+
a[s]+" != "+b[c][s]+")")},T=function(a,b,c){var d=new google.visualization.DataTable;d.addColumn("datetime","Time");d.addColumn("number",a);for(var e=0;e<b[s];e++)d.addRow([new Date(b[e]),c[e]]);0==d.getNumberOfRows()&&I("Data failed to load for graph "+a);return d},U=function(a,b){var c=google.visualization.LineChart,d=b.title,e=b.h,h=b.l,p=b.m,B=g[m]("div");B[n]("class","pagespeed-widgets");B[k](V(d,e,h,p));d=g[m]("div");d[n]("class","pagespeed-graph");B[k](d);g.getElementById("pagespeed-graphs-container")[k](B);
b.k=new c(d);b.k.draw(b.j,a.n)},V=function(a,b,c,d){var e=g[m]("div");e[n]("class","pagespeed-widgets-topbar");var h=g[m]("span");h[n]("class","pagespeed-title");h[n]("id","pagespeed-title"+d);h[k](g.createTextNode(a+": "+(100*b).toFixed(2)+"% ("));a=g[m]("a");a[n]("href",c);a[k](g.createTextNode("doc"));h[k](a);h[k](g.createTextNode(")"));e[k](h);return e};google.setOnLoadCallback(function(){var a=new J;O(a,"Resources not loaded because of fetch failures","fetch-failure",M(K("serf_fetch_failure_count"),K("serf_fetch_request_count")));O(a,"Resources not rewritten because domain wasn't authorized","not-authorized",N(K("resource_url_domain_rejections"),K("resource_url_domain_acceptances")));O(a,"Resources not rewritten because of restrictive Cache-Control headers","cache-control",N(K("num_cache_control_not_rewritable_resources"),K("num_cache_control_rewritable_resources")));
var b=L([K("cache_backend_misses"),K("cache_backend_hits")]);O(a,"Cache misses","cache-miss",M(K("cache_backend_misses"),b));O(a,"Cache lookups that were expired","cache-expired",M(K("cache_expirations"),b));O(a,"CSS files not rewritten because of parse errors","css-error",N(K("css_filter_parse_failures"),K("css_filter_blocks_rewritten")));O(a,"JavaScript minification failures","js-error",N(K("javascript_minification_failures"),K("javascript_blocks_minified")));var b=L([K("image_rewrites"),K("image_rewrites_dropped_nosaving_resize"),
K("image_rewrites_dropped_nosaving_noresize")]),c=L([K("image_norewrites_high_resolution"),K("image_rewrites_dropped_decode_failure"),K("image_rewrites_dropped_due_to_load"),K("image_rewrites_dropped_mime_type_unknown"),K("image_rewrites_dropped_server_write_fail")]);O(a,"Image rewrite failures","image-error",N(c,b));b=new Date;R(a,new Date(b-864E5),b);return a});})();

==> modpagespeed-1.9.32.4.tar.xz: modpagespeed-1.9.32.4/net/instaweb/genfiles/rewriter/console_js_opt.js <==
(function(){var f=Object,g=document,k="appendChild",l="evaluate",m="createElement",n="setAttribute",q="propertyIsEnumerable",r="push",s="length",t="prototype",u="call",v=function(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof f)return b;var c=f[t].toString[u](a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a[s]&&"undefined"!=typeof a.splice&&"undefined"!=typeof a[q]&&!a[q]("splice"))return"array";if("[object Function]"==c||"undefined"!=
typeof a[u]&&"undefined"!=typeof a[q]&&!a[q]("call"))return"function"}else return"null";else if("function"==b&&"undefined"==typeof a[u])return"object";return b},w="closure_uid_"+(1E9*Math.random()>>>0),x=0;var y="StopIteration"in this?this.StopIteration:Error("StopIteration"),z=function(){};z[t].a=function(){throw y;};z[t].d=function(){return this};var A=function(a){var b=[],c=0,d;for(d in a)b[c++]=a[d];return b};var C=function(a,b){this.a={};this.b=[];this.f=this.e=0;var c=arguments[s];if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)this.set(arguments[d],arguments[d+1])}else if(a){if(a instanceof C)D(a),d=a.b.concat(),c=a.g();else{var c=[],e=0;for(d in a)c[e++]=d;d=c;c=A(a)}for(e=0;e<d[s];e++)this.set(d[e],c[e])}};C[t].g=function(){D(this);for(var a=[],b=0;b<this.b[s];b++)a[r](this.a[this.b[b]]);return a};
var D=function(a){if(a.e!=a.b[s]){for(var b=0,c=0;b<a.b[s];){var d=a.b[b];f[t].hasOwnProperty[u](a.a,d)&&(a.b[c++]=d);b++}a.b.length=c}if(a.e!=a.b[s]){for(var e={},c=b=0;b<a.b[s];)d=a.b[b],f[t].hasOwnProperty[u](e,d)||(a.b[c++]=d,e[d]=1),b++;a.b.length=c}};C[t].set=function(a,b){f[t].hasOwnProperty[u](this.a,a)||(this.e++,this.b[r](a),this.f++);this.a[a]=b};
C[t].d=function(a){D(this);var b=0,c=this.b,d=this.a,e=this.f,h=this,p=new z;p.a=function(){for(;;){if(e!=h.f)throw Error("The map has changed since the iterator was created");if(b>=c[s])throw y;var p=c[b++];return a?p:d[p]}};return p};var E=function(a){if("function"==typeof a.g)return a.g();if("string"==typeof a)return a.split("");var b=v(a);if("array"==b||"object"==b&&"number"==typeof a[s]){for(var b=[],c=a[s],d=0;d<c;d++)b[r](a[d]);return b}return A(a)};var G=function(a){this.a=new C;a&&F(this,a)},H=function(a){var b=typeof a;return"object"==b&&a||"function"==b?"o"+(a[w]||(a[w]=++x)):b.substr(0,1)+a},F=function(a,b){for(var c=E(b),d=c[s],e=0;e<d;e++){var h=c[e];a.a.set(H(h),h)}};G[t].g=function(){return this.a.g()};G[t].d=function(){return this.a.d(!1)};google.load("visualization","1.0",{packages:["corechart"]});
var I=function(a){window.console&&console.error(a)},J=function(){this.a=[];this.f=new G;this.d=this.e=null;this.k={width:900,height:255,colors:["#4ECDC4","#556270","#C7F464"],legend:{position:"bottom"},hAxis:{format:"MMM d, y hh:mma",gridlines:{color:"#F2F2F2"},baselineColor:"#E5E5E5"},vAxis:{format:"#.###%",minValue:0,viewWindowMode:"explicit",viewWindow:{min:0},gridlines:{color:"#F2F2F2"},baselineColor:"#E5E5E5"},chartArea:{left:60,top:20,width:800},pointSize:2}},K=function(a){var b={};b.c=new G([a]);
b.evaluate=function(b){return b(a)};return b},L=function(a){var b={};b.c=new G;for(var c=0;c<a[s];c++)F(b.c,a[c].c);b.evaluate=function(b){for(var c=0,h=0;h<a[s];h++)c+=a[h][l](b);return c};return b},M=function(a,b){var c={};c.c=new G;F(c.c,a.c);F(c.c,b.c);c.evaluate=function(c){var e=b[l](c);return 0==e?0:a[l](c)/e};return c},N=function(a,b){return M(a,L([a,b]))},O=function(a,b,c,d){var e={};e.title=b;e.l="https://developers.google.com/speed/pagespeed/module/console#"+c;e.value=d;e.m=a.a[s];e.h=
null;e.priority=null;e.i=null;e.j=null;a.a[r](e);F(a.f,d.c)},P=function(a,b,c){var d=pagespeedStatisticsUrl+"?json",d=d+("&start_time="+b.getTime()),d=d+("&end_time="+c.getTime()),d=d+"&granularity=60000&var_titles=";for(b=0;b<a[s];b++)d+=a[b]+",";return d},R=function(a,b,c){var d=new XMLHttpRequest;b=P(a.f.g(),b,c);d.onreadystatechange=function(){if(4==this.readyState)if(200!=this.status||1>this.responseText[s]||"{"!=this.responseText[0])I("XHR request failed.");else{var b=JSON.parse(this.responseText);
Q(a,b)}};d.open("GET",b);d.send()},Q=function(a,b){a.e=b.variables;a.d=b.timestamps;S(a.d,a.e);for(var c=0;c<a.a[s];c++){for(var d=[],e=0;e<a.d[s];e++)d[r](a.a[c].value[l](function(a){return function(b){if(b in a)return a[b][e];I("JSON data missing required variable.")}}(a.e)));a.a[c].h=d[d[s]-1];a.a[c].priority=a.a[c].h;a.a[c].i=T(a.a[c].title,a.d,d)}a.a.sort(function(a,b){return b.priority-a.priority});for(c=0;c<a.a[s];c++)U(a,a.a[c])},S=function(a,b){for(var c in b)a[s]!=b[c][s]&&I("JSON response is malformed. ("+
a[s]+" != "+b[c][s]+")")},T=function(a,b,c){var d=new google.visualization.DataTable;d.addColumn("datetime","Time");d.addColumn("number",a);for(var e=0;e<b[s];e++)d.addRow([new Date(b[e]),c[e]]);0==d.getNumberOfRows()&&I("Data failed to load for graph "+a);return d},U=function(a,b){var c=google.visualization.LineChart,d=b.title,e=b.h,h=b.l,p=b.m,B=g[m]("div");B[n]("class","pagespeed-widgets");B[k](V(d,e,h,p));d=g[m]("div");d[n]("class","pagespeed-graph");B[k](d);g.getElementById("pagespeed-graphs-container")[k](B);
b.j=new c(d);b.j.draw(b.i,a.k)},V=function(a,b,c,d){var e=g[m]("div");e[n]("class","pagespeed-widgets-topbar");var h=g[m]("span");h[n]("class","pagespeed-title");h[n]("id","pagespeed-title"+d);h[k](g.createTextNode(a+": "+(100*b).toFixed(2)+"% ("));a=g[m]("a");a[n]("href",c);a[k](g.createTextNode("doc"));h[k](a);h[k](g.createTextNode(")"));e[k](h);return e};google.setOnLoadCallback(function(){var a=new J;O(a,"Resources not loaded because of fetch failures","fetch-failure",M(K("serf_fetch_failure_count"),K("serf_fetch_request_count")));O(a,"Resources not rewritten because domain wasn't authorized","not-authorized",N(K("resource_url_domain_rejections"),K("resource_url_domain_acceptances")));O(a,"Resources not rewritten because of restrictive Cache-Control headers","cache-control",N(K("num_cache_control_not_rewritable_resources"),K("num_cache_control_rewritable_resources")));
var b=L([K("cache_backend_misses"),K("cache_backend_hits")]);O(a,"Cache misses","cache-miss",M(K("cache_backend_misses"),b));O(a,"Cache lookups that were expired","cache-expired",M(K("cache_expirations"),b));O(a,"CSS files not rewritten because of parse errors","css-error",N(K("css_filter_parse_failures"),K("css_filter_blocks_rewritten")));O(a,"JavaScript minification failures","js-error",N(K("javascript_minification_failures"),K("javascript_blocks_minified")));var b=L([K("image_rewrites"),K("image_rewrites_dropped_nosaving_resize"),
K("image_rewrites_dropped_nosaving_noresize")]),c=L([K("image_norewrites_high_resolution"),K("image_rewrites_dropped_decode_failure"),K("image_rewrites_dropped_due_to_load"),K("image_rewrites_dropped_mime_type_unknown"),K("image_rewrites_dropped_server_write_fail")]);O(a,"Image rewrite failures","image-error",N(c,b));b=new Date;R(a,new Date(b-864E5),b);return a});})();
